/**
 returns a function which executes promises one after another

 @memberOf function
 @param promiseGenerators an array of functions which return a promise
 @return function which executes the promises
 */
const enqueue = (promiseGenerators) => {
    return (...args) => promiseGenerators.reduce((f, promiseGenerator) => {
        return (f instanceof Promise)
            ? f.then(promiseGenerator)
            : promiseGenerator(...args);
    });
};

export default enqueue;